#ifndef _NAMEDETAIL_H
#define _NAMEDETAIL_H

extern gchar *titles[];
extern gchar *suffixes[];

gboolean do_edit_name_detail(GtkWindow *parent, struct person *p);

#endif /* _NAMEDETAIL_H */
